---
title: droneci
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.droneci) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.droneci?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.droneci) [![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.droneci/src/branch/main/LICENSE)

Setup [Drone CI](https://drone.io/) base server. Drone is a Continuous Delivery system built on container technology. Drone uses a simple YAML configuration file, a superset of docker-compose, to define and execute Pipelines inside Docker containers.

<!--more-->

- [Default Variables](#default-variables)
  - [droneci_admin_user](#droneci_admin_user)
  - [droneci_container_name](#droneci_container_name)
  - [droneci_db_name](#droneci_db_name)
  - [droneci_db_password](#droneci_db_password)
  - [droneci_db_port](#droneci_db_port)
  - [droneci_db_secret](#droneci_db_secret)
  - [droneci_db_server](#droneci_db_server)
  - [droneci_db_ssl_mode](#droneci_db_ssl_mode)
  - [droneci_db_type](#droneci_db_type)
  - [droneci_db_user](#droneci_db_user)
  - [droneci_docker_socket_path](#droneci_docker_socket_path)
  - [droneci_exposed_ports](#droneci_exposed_ports)
  - [droneci_extra_hosts](#droneci_extra_hosts)
  - [droneci_gitea_oauth_client_id](#droneci_gitea_oauth_client_id)
  - [droneci_gitea_oauth_client_secret](#droneci_gitea_oauth_client_secret)
  - [droneci_gitea_server](#droneci_gitea_server)
  - [droneci_gitea_skip_verify](#droneci_gitea_skip_verify)
  - [droneci_github_client_id](#droneci_github_client_id)
  - [droneci_github_client_secret](#droneci_github_client_secret)
  - [droneci_host](#droneci_host)
  - [droneci_http_proxy](#droneci_http_proxy)
  - [droneci_https_proxy](#droneci_https_proxy)
  - [droneci_image](#droneci_image)
  - [droneci_license_key](#droneci_license_key)
  - [droneci_memory_limit](#droneci_memory_limit)
  - [droneci_memory_reservation](#droneci_memory_reservation)
  - [droneci_networks](#droneci_networks)
  - [droneci_networks_applied](#droneci_networks_applied)
  - [droneci_no_proxy](#droneci_no_proxy)
  - [droneci_privileged](#droneci_privileged)
  - [droneci_prometheus_anonymous_access](#droneci_prometheus_anonymous_access)
  - [droneci_repository_filter](#droneci_repository_filter)
  - [droneci_restart_policy](#droneci_restart_policy)
  - [droneci_scm_provider](#droneci_scm_provider)
  - [droneci_secret](#droneci_secret)
  - [droneci_service_directory](#droneci_service_directory)
  - [droneci_service_stopped](#droneci_service_stopped)
  - [droneci_user_filter](#droneci_user_filter)
  - [droneci_version](#droneci_version)
  - [droneci_volumes](#droneci_volumes)
- [Dependencies](#dependencies)

---

## Default Variables

### droneci_admin_user

#### Default value

```YAML
droneci_admin_user: _unset_
```

### droneci_container_name

#### Default value

```YAML
droneci_container_name: droneci
```

### droneci_db_name

#### Default value

```YAML
droneci_db_name: droneci
```

### droneci_db_password

#### Default value

```YAML
droneci_db_password: secure
```

### droneci_db_port

#### Default value

```YAML
droneci_db_port: 5432
```

### droneci_db_secret

Drone supports aesgcm encryption of secrets stored in the database. You must enable encryption before any secrets are stored in the database! You can generate an encryption key with e.g. `openssl rand -hex 16`.

#### Default value

```YAML
droneci_db_secret: _unset_
```

#### Example usage

```YAML
droneci_db_secret: 0c549fd39ae397333761d2cb0c53c219
```

### droneci_db_server

#### Default value

```YAML
droneci_db_server: localhost
```

### droneci_db_ssl_mode

#### Default value

```YAML
droneci_db_ssl_mode: disable
```

### droneci_db_type

#### Default value

```YAML
droneci_db_type: sqlite
```

### droneci_db_user

#### Default value

```YAML
droneci_db_user: pgdroneci
```

### droneci_docker_socket_path

#### Default value

```YAML
droneci_docker_socket_path: /var/run/docker.sock
```

### droneci_exposed_ports

#### Default value

```YAML
droneci_exposed_ports:
  - 127.0.0.1:8080:80
```

### droneci_extra_hosts

#### Default value

```YAML
droneci_extra_hosts: []
```

### droneci_gitea_oauth_client_id

#### Default value

```YAML
droneci_gitea_oauth_client_id: _unset_
```

#### Example usage

```YAML
droneci_gitea_oauth_client_id: 1111-222-33333-44444
```

### droneci_gitea_oauth_client_secret

#### Default value

```YAML
droneci_gitea_oauth_client_secret: _unset_
```

#### Example usage

```YAML
droneci_gitea_oauth_client_secret: 1234abcd5678efgh
```

### droneci_gitea_server

#### Default value

```YAML
droneci_gitea_server: http://my-git.example.com
```

### droneci_gitea_skip_verify

#### Default value

```YAML
droneci_gitea_skip_verify: false
```

### droneci_github_client_id

#### Default value

```YAML
droneci_github_client_id: _unset_
```

### droneci_github_client_secret

#### Default value

```YAML
droneci_github_client_secret: _unset_
```

### droneci_host

#### Default value

```YAML
droneci_host: http://localhost
```

### droneci_http_proxy

#### Default value

```YAML
droneci_http_proxy: _unset_
```

### droneci_https_proxy

#### Default value

```YAML
droneci_https_proxy: _unset_
```

### droneci_image

#### Default value

```YAML
droneci_image: drone/drone:{{ droneci_version }}
```

### droneci_license_key

#### Default value

```YAML
droneci_license_key: _unset_
```

### droneci_memory_limit

#### Default value

```YAML
droneci_memory_limit: _unset_
```

#### Example usage

```YAML
droneci_memory_limit: 512m
```

### droneci_memory_reservation

#### Default value

```YAML
droneci_memory_reservation: _unset_
```

#### Example usage

```YAML
droneci_memory_reservation: 256m
```

### droneci_networks

#### Default value

```YAML
droneci_networks:
  - name: default
```

#### Example usage

```YAML
droneci_networks:
  - name: default
    # optional network driver, defaults to 'bride'
    driver: host
```

### droneci_networks_applied

#### Default value

```YAML
droneci_networks_applied:
  - default
```

### droneci_no_proxy

#### Default value

```YAML
droneci_no_proxy:
  - drone-server
  - drone-agent
```

### droneci_privileged

#### Default value

```YAML
droneci_privileged: false
```

### droneci_prometheus_anonymous_access

#### Default value

```YAML
droneci_prometheus_anonymous_access: false
```

### droneci_repository_filter

Optional comma-separated list of accounts, used to limit which repositories are syncronized between your source control management system and Drone.

#### Default value

```YAML
droneci_repository_filter: []
```

### droneci_restart_policy

#### Default value

```YAML
droneci_restart_policy: always
```

### droneci_scm_provider

SCM provider to use with Drone (gitea|github)

#### Default value

```YAML
droneci_scm_provider: none
```

### droneci_secret

#### Default value

```YAML
droneci_secret: myveryownsecret
```

### droneci_service_directory

#### Default value

```YAML
droneci_service_directory: /var/lib/docker/services/droneci
```

### droneci_service_stopped

#### Default value

```YAML
droneci_service_stopped: false
```

### droneci_user_filter

#### Default value

```YAML
droneci_user_filter: []
```

### droneci_version

#### Default value

```YAML
droneci_version: 1.6.0
```

### droneci_volumes

> Define required docker volumes.

#### Default value

```YAML
droneci_volumes:
  - name: data
    dest: /var/lib/drone
    bind: false
```

#### Example usage

```YAML
droneci_volumes:
  # Instead of the name you could specify a path on the container host system,
  # but you also have to enable bind mount for this volume
  - name: data
    # target location inside the container
    dest: /var/lib/drone
    # enable bind mount, if false volume will be configured as named volume
    # keep in mind you MUST set bind in any case
    bind: True
```



## Dependencies

None.
